@@ -11,6 +11,7 @@ require "pathname"
 SPEC_ROOT = Pathname(__FILE__).dirname
 
 begin
+  require "debug"
   require "pry"
   require "pry-byebug"
 rescue LoadError
@@ -22,6 +23,8 @@ require "dry/monads/all"
 
 Dir["./spec/shared/**/*.rb"].each { |f| require f }
 
+Warning.ignore(/rspec-expectations/)
+Warning.ignore(/super_diff/)
 Warning.process { raise _1 }
 
 module Kernel
